1.0.0 API documentation: fast_trigonometry.hpp File Reference

| 1.0.0 API documentation

Functions
fast_trigonometry.hpp File Reference

GLM_GTX_fast_trigonometry More...

Go to the source code of this file.

## Functions
template<typename T >
GLM_FUNC_DECL T | fastAcos (T angle)
| Faster than the common acos function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastAsin (T angle)
| Faster than the common asin function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastAtan (T angle)
| Faster than the common atan function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastAtan (T y, T x)
| Faster than the common atan function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastCos (T angle)
| Faster than the common cos function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastSin (T angle)
| Faster than the common sin function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | fastTan (T angle)
| Faster than the common tan function but less accurate. More...
template<typename T >
GLM_FUNC_DECL T | wrapAngle (T angle)
| Wrap an angle to [0 2pi[ From GLM_GTX_fast_trigonometry extension.

## Detailed Description

GLM_GTX_fast_trigonometry

See also
  Core features (dependence)

Definition in file fast_trigonometry.hpp.